function createPolygon(id, x, y, tab)
  local o = {}
  o.id = id
  o.b = love.physics.newBody(world, x, y, "dynamic")
  o.s = love.physics.newPolygonShape( unpack(tab) )
  o.f = love.physics.newFixture(o.b, o.s)
  
  table.insert(objects, o)
end

function love.load()
  world = love.physics.newWorld(0, 0)
  objects = {}
  
  --Table for coords of every polygon
  tt = {}
end

function love.update(dt)
  world:update(dt)
end

function love.draw()
  debugWorldDraw(world)
  love.graphics.setColor(255, 0, 0)
  
  if #tt > 2 then
    love.graphics.line(tt)
  end
  
  if #tt > 1 then
    local x = tt[#tt-1]
    local y = tt[#tt]
    love.graphics.line(x, y, love.mouse.getX(), love.mouse.getY())
    
    for i=1, #tt, 2 do
      love.graphics.print("x: " .. tt[i] .. " y: " .. tt[i+1], 10 + i*50, 10)
    end
  end
  
  for i=1, #tt/2, 2 do
    love.graphics.circle("fill", tt[i], tt[i+1], 3)
  end
end

function love.mousepressed(x,y, button)
  --Create polygon (LMouse for add vertex, RMouse for create polygon (if >= 3 vertex))
  --If vertex >= 16 than polygon automatically creates
    if button == "l" then
      if #tt == 16 then
        createPolygon("pol", 0, 0, tt)
        tt = {}
      else
        --Add vertex in array
        table.insert(tt, x)
        table.insert(tt, y)
      end
    end
    
    if button == "r" and #tt >= 6 then
      createPolygon("pol", 0, 0, tt)
    end
    
    if button == "r" then --If <= 3 points, simply erase array
      tt = {}
    end
end



-----------DEBUG
function debugWorldDraw(world)
  local bodies = world:getBodyList()
  
  for b=#bodies,1,-1 do
    local body = bodies[b]
    local bx,by = body:getPosition()
    local bodyAngle = body:getAngle()
    love.graphics.push()
    love.graphics.translate(bx,by)
    love.graphics.rotate(bodyAngle)
    
    math.randomseed(1) --for color generation
    
    local fixtures = body:getFixtureList()
    for i=1,#fixtures do
      local fixture = fixtures[i]
      local shape = fixture:getShape()
      local shapeType = shape:getType()
      local isSensor = fixture:isSensor()
      
      if (isSensor) then
        love.graphics.setColor(0,0,255,96)
      else
        love.graphics.setColor(math.random(32,200),math.random(32,200),math.random(32,200),96)
      end
      
      love.graphics.setLineWidth(1)
      if (shapeType == "circle") then
        local x,y = fixture:getMassData() --0.9.0 missing circleshape:getPoint()
        --local x,y = shape:getPoint() --0.9.1
        local radius = shape:getRadius()
        love.graphics.circle("fill",x,y,radius,15)
        love.graphics.setColor(0,0,0,255)
        love.graphics.circle("line",x,y,radius,15)
        local eyeRadius = radius/4
        love.graphics.setColor(0,0,0,255)
        love.graphics.circle("fill",x+radius-eyeRadius,y,eyeRadius,10)
      elseif (shapeType == "polygon") then
        local points = {shape:getPoints()}
        love.graphics.polygon("fill",points)
        love.graphics.setColor(0,0,0,255)
        love.graphics.polygon("line",points)
      elseif (shapeType == "edge") then
        love.graphics.setColor(0,0,0,255)
        love.graphics.line(shape:getPoints())
      elseif (shapeType == "chain") then
        love.graphics.setColor(0,0,0,255)
        love.graphics.line(shape:getPoints())
      end
    end
    love.graphics.pop()
  end
  
  local joints = world:getJointList()
  for index,joint in pairs(joints) do
    love.graphics.setColor(0,255,0,255)
    local x1,y1,x2,y2 = joint:getAnchors()
    if (x1 and x2) then
      love.graphics.setLineWidth(3)
      love.graphics.line(x1,y1,x2,y2)
    else
      love.graphics.setPointSize(3)
      if (x1) then
        love.graphics.point(x1,y1)
      end
      if (x2) then
        love.graphics.point(x2,y2)
      end
    end
  end
  
  local contacts = world:getContactList()
  for i=1,#contacts do
    love.graphics.setColor(255,0,0,255)
    love.graphics.setPointSize(3)
    local x1,y1,x2,y2 = contacts[i]:getPositions()
    if (x1) then
      love.graphics.point(x1,y1)
    end
    if (x2) then
      love.graphics.point(x2,y2)
    end
  end
end
